import { ChartDataService } from '../../services/chart-data.service';
import { SeriesStyle } from '../../interfaces/SeriesStyle';
export class PopoverContentMulti {
    constructor() {
        this.displays = [];
    }
    activeDataHandler(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Multi) {
            return;
        }
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data[0]);
        }
        this.displays = newValue.data
            .map((d, i) => {
            const x = d[newValue.activeIndex].x;
            const y = d[newValue.activeIndex].y;
            this.xDisplayValue = ChartDataService.xFormatter(this.period, newValue.axisConfigs.x, x);
            return {
                color: newValue.seriesMeta[i].color,
                name: newValue.seriesMeta[i].name,
                netNegative: newValue.seriesMeta[i].netNegative,
                x,
                y,
                yDisplayValue: ChartDataService.yFormatter(newValue.axisConfigs.y, y),
                delta: PopoverContentMulti.getDelta(d, newValue.activeIndex)
            };
        });
    }
    static getDelta(data, activeIndex) {
        if (activeIndex === 0) {
            return undefined;
        }
        const prevY = parseInt(data[activeIndex - 1].y, 10);
        const y = parseInt(data[activeIndex].y, 10);
        const modifier = (y - prevY >= 0) ? 1 : -1;
        return Math.round(100 * Math.abs(y - prevY) / Math.abs(prevY) * modifier);
    }
    getStyle(color) {
        return {
            'background-color': color
        };
    }
    render() {
        return (this.activeData) ? [
            h("div", null,
                h("div", null, this.xDisplayValue),
                h("table", { class: "anj-metric-wrapper" }, this.displays.map((disp) => h("tr", null,
                    h("td", null,
                        h("span", { class: "anj-legend-color", style: this.getStyle(disp.color) })),
                    h("td", { class: "anj-label" }, disp.name),
                    h("td", { class: "anj-value" }, disp.yDisplayValue),
                    h("td", null,
                        h("anj-delta", { delta: disp.delta, period: this.period, netNegative: disp.netNegative }))))))
        ] : undefined;
    }
    static get is() { return "anj-popover-content-multi"; }
    static get properties() { return {
        "activeData": {
            "type": "Any",
            "attr": "active-data",
            "watchCallbacks": ["activeDataHandler"]
        }
    }; }
    static get style() { return "/**style-placeholder:anj-popover-content-multi:**/"; }
}
